@@ -456,7 +456,19 @@ video_pojie = lambda url: 'http://okjx.cc/?url=' + url
 html_node_text = lambda HTML, XPATH: html_decode.unescape(
     html_clean(str(etree.tostring(etree.HTML(HTML).xpath(XPATH)[0])))).lstrip("b'").rstrip("'")
 """
+单节点方法，xpath列表请调用html_nodes_text方法
 HTML: Web site source code
 XPATH: Node XPATH Syntax
 retur: Node, the front page display text data
 """
+
+def html_nodes_text(XPATH_list):
+    """
+    :param XPATH_list: Type == list 传入Xpath匹配到的节点群
+    :return: Type == list 返回清洗后HTML标签后的文本
+    """
+    text_list = []
+    for Xpath in XPATH_list:
+        result = html_decode.unescape(html_clean(str(etree.tostring(Xpath)))).lstrip("b'").rstrip("'")
+        text_list.append(result)
+    return text_list
